"""Import Service modules"""
from .boot_time import Boot
from .cpu import Cpu
from .disk import Disk
from .globals import Global
from .memory import Memory
from .network import Network
from .slack import Slack
from .system import System
